@@ -91,7 +91,7 @@ def _require_array_ranges(ranges):
 
 # print iterations progress bar -- from stack overflow
 # https://stackoverflow.com/questions/3173320/text-progress-bar-in-the-console
-def _print_progress_bar (iteration, total, prefix = '', suffix = '', 
+def print_progress_bar (iteration, total, prefix = '', suffix = '', 
   decimals = 1, length = 100, fill = '█', printEnd = "\r"):
     
     # Call in a loop to create terminal progress bar
@@ -195,6 +195,13 @@ class ArgumentParser(argparse.ArgumentParser):
     elif arguments.log_level == "critical":
       log.setLevel(logging.CRITICAL)
 
+    # if localhost then set no-verify to true
+    # (docker has no security certificate)
+    if arguments.host == 'https://localhost':
+      if not arguments.no_verify:
+        arguments.no_verify = True
+        log.info("Using --no-verify with https://localhost.")
+
     return arguments
 
 class Connection(object):
@@ -218,30 +225,28 @@ class Connection(object):
     # proxies default to ""
     proxies = keywords.get("proxies", {"http": "", "https": ""})
     
-    # certificate verification is disabled unless specifically requested
-    verify = True
-    if keywords.get("verify") == "False":
-      verify = False
-    elif not keywords.get("verify"):
-      verify = False
+    # verfiy set according to arguments
+    verify = keywords.get("verify")
 
-    # resolve host alias
-    host_alias = urlparse(host)
-    host_alias = host_alias.netloc
-    try:
-      host_ip = socket.gethostbyname(host_alias)
-      host_name = socket.gethostbyaddr(host_ip)
-      host_name = host_name[0]
-    except:
-      log.error("Could not locate host: %s", (host))
-      sys.exit(1)
+    # # resolve host alias
+    # host_alias = urlparse(host)
+    # host_alias = host_alias.netloc
+    # try:
+    #   host_ip = socket.gethostbyname(host_alias)
+    #   host_name = socket.gethostbyaddr(host_ip)
+    #   host_name = host_name[0]
+    # except:
+    #   log.error("Could not locate host: %s", (host))
+    #   sys.exit(1)
 
     # host and port
     self.host = host
 
     # localhost will alias to docker, which won't work
-    if host != 'https://localhost':
-      self.host = host.replace(host_alias, host_name)
+    # if host != 'https://localhost':
+    #   self.host = host.replace(host_alias, host_name)
+    
+    # set port
     if port:
       self.host = self.host + ':' + port
 
@@ -271,6 +276,11 @@ class Connection(object):
       except KerberosExchangeError:
         log.error("Could not find Kerberos ticket, try running 'kinit'.")
         sys.exit(1)
+      
+      except requests.exceptions.SSLError:
+        log.error ("Could not find valid SSL certificiate, try re-running with --no-verify, " +
+                   "or supply your own certificate with --verify.")
+        sys.exit(1)
 
       if response.status_code == 401:
         log.error(
@@ -392,7 +402,7 @@ class Connection(object):
     # log any errors to slypi
     except:
       log.debug(log_message)
-      log.error("%s" % log_message)
+      # log.error("(request) %s" % log_message)
       raise
 
   #######################################################################
@@ -1616,7 +1626,7 @@ class Connection(object):
       
       # print progress bar if desired
       if progress:
-        print('Uploading "%s":' % file_list[fid])
+        print('Uploading "%s".' % file_list[fid])
 
       # split each file into slices
       with open(file_list[fid], "rb") as file:
@@ -1633,8 +1643,8 @@ class Connection(object):
           file_slices_uploaded[fid] += 1
 
           if progress:
-            _print_progress_bar(file_slices_uploaded[fid], file_slices_to_upload[fid], 
-              prefix = 'Progress:', suffix = 'Complete', length = 50)
+            print_progress_bar(file_slices_uploaded[fid], file_slices_to_upload[fid], 
+              prefix = 'Uploading:', suffix = 'Complete', length = 50)
 
     # finish upload
     self.post_upload_finished(uid, file_slices_uploaded)
@@ -1665,6 +1675,7 @@ def connect(arguments, **keywords):
   # keywords get passed into the actual requests
 
   # check for --no-verify or security certificate
+  keywords["verify"] = True
   if arguments.no_verify:
     keywords["verify"] = False
   elif arguments.verify is not None:
