@@ -136,6 +136,12 @@ class ArgumentParser(argparse.ArgumentParser):
         # parse arguments
         return argparse.ArgumentParser.parse_known_args(self, list_input)
 
+# TDMS error handling
+class ArgumentError (Exception):
+
+    # exception for TDMS upload problems
+    def __init__(self, message):
+        self.message = message
 
 # starts slypi ensemble logger
 def init_logger(log_file=None, log_level=DEFAULT_LOG_LEVEL):
@@ -351,7 +357,8 @@ class PluginTemplate:
         for i in range(0, num_files, num_engines):
             
             # get block of files
-            block_files = [batch_files[j] for j in range(i, i + num_engines) if j < num_files]
+            block_files = [os.path.abspath(batch_files[j])
+                for j in range(i, i + num_engines) if j < num_files]
 
             # push out jobs per engine
             async_results = []
@@ -368,7 +375,7 @@ class PluginTemplate:
 
                 # get items in order they were put into queue
                 async_result = async_results.pop(0)
-
+                
                 # retrieve data from result
                 data += async_result.get()
 
@@ -382,7 +389,7 @@ class PluginTemplate:
 
     # helper function to read in a batch of files
     def _get_file_batch(self, batch_files, file_type=None, flatten=True):
-                
+        
         # read all files into list
         data = []
         for i in range(len(batch_files)):
