@@ -78,7 +78,7 @@ class Table:
     # the ensemble information is stored internally using all available
     # information, for example full file names.
     def __init__(self, log, data_frame=None, csv_file=None, ensemble_spec=None, 
-                 file_spec=None, header=None):
+                 file_spec=None, header=None, no_index=False):
 
         # logger to use
         self.log = log
@@ -95,7 +95,10 @@ class Table:
         elif csv_file is not None:
 
             # load csv file into data frame
-            self.table = pd.read_csv(csv_file, index_col=0)
+            if no_index:
+                self.table = pd.read_csv(csv_file)
+            else:
+                self.table = pd.read_csv(csv_file, index_col=0)
 
         # otherwise use ensemble specifier
         elif ensemble_spec is not None:
@@ -384,13 +387,13 @@ class Table:
         Returns:
             sim_files (list): list of list of files matching specifier
         """
-
+    
         # if not parallel, just get all sim files normally
         if not parallel:
             return self._get_sim_files(ensemble_dirs)
-
+              
         # otherwise start parallel version
-
+        
         # parallel operation, using direct view
         rc = Client()
         view = rc.load_balanced_view()
@@ -406,8 +409,8 @@ class Table:
         async_results = []
         for i in range(num_engines):
 
-            # get block of ensemble directories to expand
-            block_dirs = [ensemble_dirs[j] 
+            # get block of ensemble directories to expand, as absolute path for ipyparallel
+            block_dirs = [os.path.abspath(ensemble_dirs[j])
                 for j in range(i*block_size, i*block_size + block_size) if j < num_dirs]
 
             # expand ensemble directories as nodes are available
@@ -424,8 +427,16 @@ class Table:
             # get items in order they were put into queue
             async_result = async_results.pop(0)
 
+            # convert back to relative paths
+            abs_paths = async_result.get()
+            rel_paths = []
+            cwd = os.getcwd()
+            for ap in abs_paths:
+                rel_paths.append([Path(os.path.relpath(p, cwd)).as_posix() 
+                                  for p in ap])
+
             # retrieve data from result
-            sim_files += async_result.get()
+            sim_files += rel_paths
 
         # clean up ipyparallel
         rc.purge_everything()
@@ -437,7 +448,7 @@ class Table:
 
     # get simulation files for a block of ensemble directories
     def _get_sim_files (self, ensemble_dirs):
-
+    
         sim_files = []
         for i in range(len(ensemble_dirs)):
 
@@ -446,7 +457,7 @@ class Table:
 
             # add files to list
             sim_files.append(files_to_convert)
-        
+
         return sim_files
 
     # convert an input file specifier to an output file specifier
@@ -696,7 +707,7 @@ def parse_d_format(log, d_str):
     in_brackets = right_brackets[0]
 
     # check that between brackets has only : or digits
-    if len(re.findall('[^:\-\d]', in_brackets)) > 0:
+    if len(re.findall(r'[^:\-\d]', in_brackets)) > 0:
         log.error('Invalid %d[::] format, ' +
             'can only have integers between "[]": %s' % d_str)
         raise EnsembleSpecifierError(d_str, 'can only have integers between "[]"')
@@ -756,10 +767,9 @@ def parse_d_format(log, d_str):
         raise EnsembleSpecifierError(d_str, 'must have non-zero step between "[]"')
 
     return root, start, stop, step, ext
-
-
+    
 # factory method to combine tables
-def combine (log, tables, ignore_index=False):
+def combine (log, tables, ignore_index=False, no_index=False):
     """
     Combines multiple tables to create a new table.  Tables are assumed
     to have identical index values and are joined as columns.
@@ -768,11 +778,12 @@ def combine (log, tables, ignore_index=False):
         log (logger object): logger for writing output
         tables (list): list of ensemble tables to combine
         ignore_index (bool): ignore index values and join as rows
+        no_index (bool): assume no index column and join as rows (over-rides ignore_index)
 
     Returns:
         combined_table (Table): ensemble table made up of input tables
     """
-    
+
     # if no tables are given, return empty table
     if len(tables) == 0:
         return Table(log)
@@ -784,8 +795,12 @@ def combine (log, tables, ignore_index=False):
     pd_tables = []
     for table in tables:
 
+        # check if we aren't using indices
+        if no_index:
+            reset_table = table.table
+
         # check that indices are identical
-        if not ignore_index:
+        elif not ignore_index:
             if not np.array_equal(table.table.index.to_numpy(), 
                                   tables[0].table.index.to_numpy()):
                 log.error("Indices do not match -- tables cannot be combined. " +
@@ -802,9 +817,14 @@ def combine (log, tables, ignore_index=False):
     
         # remove Table information, leaving only pandas table
         pd_tables.append(reset_table)
-        
+    
+    if no_index:
+        concat_table = pd.concat(pd_tables, axis=1, join='inner')
+    else:
+        concat_table = pd.concat(pd_tables, axis=1, join='inner', verify_integrity=True)
+
     # concatenate tables
-    return Table(log, data_frame=pd.concat(pd_tables, axis=1, join='inner', verify_integrity=True))
+    return Table(log, data_frame=concat_table)
 
 
 # factory method to explode a table using a column of lists
